@@ -1,4 +1,5 @@
 import base64
+from datetime import datetime
 import functools
 import json
 import requests
@@ -32,7 +33,6 @@ class MyResourceProtector(ResourceProtector):
             return True
         except Exception as error:
             self.logger.error(f"Acquiring token failed {error}")
-            self.logger.error(f'{error.__traceback__}')
             return False
 
     def acquire_token(self, permissions=None):
@@ -43,8 +43,6 @@ class MyResourceProtector(ResourceProtector):
         """
         request = HttpRequest(_req.method, _req.full_path, _req.data, _req.headers)
         request.req = _req
-        self.logger.info(f"REQUEST {_req}")
-        self.logger.info(f"REQUEST PARAMS {_req.method} {_req.full_path} {_req.data} {_req.headers}")
         # backward compatible
         if isinstance(permissions, str):
             permissions = [permissions]
@@ -141,7 +139,8 @@ class JWTValidator(BearerTokenValidator, ABC):
         super_admin_role="role_super_admin",
         remote_token_validation=False,
         remote_public_key=False,
-        **extra_attributes
+        realm_cache_sync_time=900,
+        **extra_attributes,
     ):
         super().__init__(**extra_attributes)
         self.static_issuer = static_issuer
@@ -159,6 +158,7 @@ class JWTValidator(BearerTokenValidator, ABC):
         self.super_admin_role = super_admin_role
         self.remote_token_validation = remote_token_validation
         self.remote_public_key = remote_public_key
+        self.realm_cache_sync_time = realm_cache_sync_time
         if role_permission_file_location:
             try:
                 role_permission_file = open(role_permission_file_location)
@@ -225,7 +225,23 @@ class JWTValidator(BearerTokenValidator, ABC):
         if issuer in self.realms:
             if self.remote_public_key:
                 return {"public_key": self.remote_public_key}
-            return requests.get(issuer).json()
+            else:
+                f = open("realm_config_cache.json", "a")
+                realm_config_cache = json.load(f)
+                current_time = datetime.timestamp(datetime.now())
+                if (
+                    issuer in realm_config_cache
+                    and (
+                        current_time - realm_config_cache[issuer]["last_sync_time"]
+                        > self.realm_cache_sync_time
+                    )
+                ) or (issuer not in realm_config_cache):
+                    upstream_realm_config = requests.get(issuer).json()
+                    upstream_realm_config["last_sync_time"] = current_time
+                    realm_config_cache[issuer] = upstream_realm_config
+                    f.write(json.dumps(realm_config_cache))
+                f.close()
+                return realm_config_cache[issuer]
         return {}
 
     def validate_token(self, token, permissions, request):
